PayuPaymentResult class

Result object that returns in the end of transaction It's directly put as it is no changes are made in this response

Constructors

PayuPaymentResult({Map? response, String? status})

Properties

hashCode int
The hash code for this object.
no setterinherited
response Map?
Response from Native SDK
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
Status of transaction part of which computed in dart code
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited